@@ -20,8 +20,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from ._jsii import *
 
@@ -45,15 +45,15 @@ class CfnMicrosoftAD(
     def __init__(
         self,
         scope: aws_cdk.core.Construct,
-        id: str,
+        id: builtins.str,
         *,
-        name: str,
-        password: str,
+        name: builtins.str,
+        password: builtins.str,
         vpc_settings: typing.Union["VpcSettingsProperty", aws_cdk.core.IResolvable],
-        create_alias: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]] = None,
-        edition: typing.Optional[str] = None,
-        enable_sso: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]] = None,
-        short_name: typing.Optional[str] = None,
+        create_alias: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]] = None,
+        edition: typing.Optional[builtins.str] = None,
+        enable_sso: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]] = None,
+        short_name: typing.Optional[builtins.str] = None,
     ) -> None:
         """Create a new ``AWS::DirectoryService::MicrosoftAD``.
 
@@ -92,45 +92,46 @@ class CfnMicrosoftAD(
 
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(
-        self, props: typing.Mapping[str, typing.Any]
-    ) -> typing.Mapping[str, typing.Any]:
+        self,
+        props: typing.Mapping[builtins.str, typing.Any],
+    ) -> typing.Mapping[builtins.str, typing.Any]:
         """
         :param props: -
         """
         return jsii.invoke(self, "renderProperties", [props])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrAlias")
-    def attr_alias(self) -> str:
+    def attr_alias(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: Alias
         """
         return jsii.get(self, "attrAlias")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrDnsIpAddresses")
-    def attr_dns_ip_addresses(self) -> typing.List[str]:
+    def attr_dns_ip_addresses(self) -> typing.List[builtins.str]:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: DnsIpAddresses
         """
         return jsii.get(self, "attrDnsIpAddresses")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="name")
-    def name(self) -> str:
+    def name(self) -> builtins.str:
         """``AWS::DirectoryService::MicrosoftAD.Name``.
 
         see
@@ -138,13 +139,13 @@ class CfnMicrosoftAD(
         """
         return jsii.get(self, "name")
 
-    @name.setter
-    def name(self, value: str) -> None:
+    @name.setter # type: ignore
+    def name(self, value: builtins.str) -> None:
         jsii.set(self, "name", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="password")
-    def password(self) -> str:
+    def password(self) -> builtins.str:
         """``AWS::DirectoryService::MicrosoftAD.Password``.
 
         see
@@ -152,11 +153,11 @@ class CfnMicrosoftAD(
         """
         return jsii.get(self, "password")
 
-    @password.setter
-    def password(self, value: str) -> None:
+    @password.setter # type: ignore
+    def password(self, value: builtins.str) -> None:
         jsii.set(self, "password", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="vpcSettings")
     def vpc_settings(
         self,
@@ -168,17 +169,18 @@ class CfnMicrosoftAD(
         """
         return jsii.get(self, "vpcSettings")
 
-    @vpc_settings.setter
+    @vpc_settings.setter # type: ignore
     def vpc_settings(
-        self, value: typing.Union["VpcSettingsProperty", aws_cdk.core.IResolvable]
+        self,
+        value: typing.Union["VpcSettingsProperty", aws_cdk.core.IResolvable],
     ) -> None:
         jsii.set(self, "vpcSettings", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="createAlias")
     def create_alias(
         self,
-    ) -> typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]:
+    ) -> typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]]:
         """``AWS::DirectoryService::MicrosoftAD.CreateAlias``.
 
         see
@@ -186,15 +188,16 @@ class CfnMicrosoftAD(
         """
         return jsii.get(self, "createAlias")
 
-    @create_alias.setter
+    @create_alias.setter # type: ignore
     def create_alias(
-        self, value: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]
+        self,
+        value: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]],
     ) -> None:
         jsii.set(self, "createAlias", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="edition")
-    def edition(self) -> typing.Optional[str]:
+    def edition(self) -> typing.Optional[builtins.str]:
         """``AWS::DirectoryService::MicrosoftAD.Edition``.
 
         see
@@ -202,15 +205,15 @@ class CfnMicrosoftAD(
         """
         return jsii.get(self, "edition")
 
-    @edition.setter
-    def edition(self, value: typing.Optional[str]) -> None:
+    @edition.setter # type: ignore
+    def edition(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "edition", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="enableSso")
     def enable_sso(
         self,
-    ) -> typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]:
+    ) -> typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]]:
         """``AWS::DirectoryService::MicrosoftAD.EnableSso``.
 
         see
@@ -218,15 +221,16 @@ class CfnMicrosoftAD(
         """
         return jsii.get(self, "enableSso")
 
-    @enable_sso.setter
+    @enable_sso.setter # type: ignore
     def enable_sso(
-        self, value: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]
+        self,
+        value: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]],
     ) -> None:
         jsii.set(self, "enableSso", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="shortName")
-    def short_name(self) -> typing.Optional[str]:
+    def short_name(self) -> typing.Optional[builtins.str]:
         """``AWS::DirectoryService::MicrosoftAD.ShortName``.
 
         see
@@ -234,8 +238,8 @@ class CfnMicrosoftAD(
         """
         return jsii.get(self, "shortName")
 
-    @short_name.setter
-    def short_name(self, value: typing.Optional[str]) -> None:
+    @short_name.setter # type: ignore
+    def short_name(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "shortName", value)
 
     @jsii.data_type(
@@ -244,7 +248,12 @@ class CfnMicrosoftAD(
         name_mapping={"subnet_ids": "subnetIds", "vpc_id": "vpcId"},
     )
     class VpcSettingsProperty:
-        def __init__(self, *, subnet_ids: typing.List[str], vpc_id: str) -> None:
+        def __init__(
+            self,
+            *,
+            subnet_ids: typing.List[builtins.str],
+            vpc_id: builtins.str,
+        ) -> None:
             """
             :param subnet_ids: ``CfnMicrosoftAD.VpcSettingsProperty.SubnetIds``.
             :param vpc_id: ``CfnMicrosoftAD.VpcSettingsProperty.VpcId``.
@@ -252,33 +261,37 @@ class CfnMicrosoftAD(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-directoryservice-microsoftad-vpcsettings.html
             """
-            self._values = {
+            self._values: typing.Dict[str, typing.Any] = {
                 "subnet_ids": subnet_ids,
                 "vpc_id": vpc_id,
             }
 
         @builtins.property
-        def subnet_ids(self) -> typing.List[str]:
+        def subnet_ids(self) -> typing.List[builtins.str]:
             """``CfnMicrosoftAD.VpcSettingsProperty.SubnetIds``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-directoryservice-microsoftad-vpcsettings.html#cfn-directoryservice-microsoftad-vpcsettings-subnetids
             """
-            return self._values.get("subnet_ids")
+            result = self._values.get("subnet_ids")
+            assert result is not None, "Required property 'subnet_ids' is missing"
+            return result
 
         @builtins.property
-        def vpc_id(self) -> str:
+        def vpc_id(self) -> builtins.str:
             """``CfnMicrosoftAD.VpcSettingsProperty.VpcId``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-directoryservice-microsoftad-vpcsettings.html#cfn-directoryservice-microsoftad-vpcsettings-vpcid
             """
-            return self._values.get("vpc_id")
+            result = self._values.get("vpc_id")
+            assert result is not None, "Required property 'vpc_id' is missing"
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -304,13 +317,13 @@ class CfnMicrosoftADProps:
     def __init__(
         self,
         *,
-        name: str,
-        password: str,
+        name: builtins.str,
+        password: builtins.str,
         vpc_settings: typing.Union["CfnMicrosoftAD.VpcSettingsProperty", aws_cdk.core.IResolvable],
-        create_alias: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]] = None,
-        edition: typing.Optional[str] = None,
-        enable_sso: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]] = None,
-        short_name: typing.Optional[str] = None,
+        create_alias: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]] = None,
+        edition: typing.Optional[builtins.str] = None,
+        enable_sso: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]] = None,
+        short_name: typing.Optional[builtins.str] = None,
     ) -> None:
         """Properties for defining a ``AWS::DirectoryService::MicrosoftAD``.
 
@@ -325,7 +338,7 @@ class CfnMicrosoftADProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "name": name,
             "password": password,
             "vpc_settings": vpc_settings,
@@ -340,22 +353,26 @@ class CfnMicrosoftADProps:
             self._values["short_name"] = short_name
 
     @builtins.property
-    def name(self) -> str:
+    def name(self) -> builtins.str:
         """``AWS::DirectoryService::MicrosoftAD.Name``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html#cfn-directoryservice-microsoftad-name
         """
-        return self._values.get("name")
+        result = self._values.get("name")
+        assert result is not None, "Required property 'name' is missing"
+        return result
 
     @builtins.property
-    def password(self) -> str:
+    def password(self) -> builtins.str:
         """``AWS::DirectoryService::MicrosoftAD.Password``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html#cfn-directoryservice-microsoftad-password
         """
-        return self._values.get("password")
+        result = self._values.get("password")
+        assert result is not None, "Required property 'password' is missing"
+        return result
 
     @builtins.property
     def vpc_settings(
@@ -366,52 +383,58 @@ class CfnMicrosoftADProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html#cfn-directoryservice-microsoftad-vpcsettings
         """
-        return self._values.get("vpc_settings")
+        result = self._values.get("vpc_settings")
+        assert result is not None, "Required property 'vpc_settings' is missing"
+        return result
 
     @builtins.property
     def create_alias(
         self,
-    ) -> typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]:
+    ) -> typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]]:
         """``AWS::DirectoryService::MicrosoftAD.CreateAlias``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html#cfn-directoryservice-microsoftad-createalias
         """
-        return self._values.get("create_alias")
+        result = self._values.get("create_alias")
+        return result
 
     @builtins.property
-    def edition(self) -> typing.Optional[str]:
+    def edition(self) -> typing.Optional[builtins.str]:
         """``AWS::DirectoryService::MicrosoftAD.Edition``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html#cfn-directoryservice-microsoftad-edition
         """
-        return self._values.get("edition")
+        result = self._values.get("edition")
+        return result
 
     @builtins.property
     def enable_sso(
         self,
-    ) -> typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]:
+    ) -> typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]]:
         """``AWS::DirectoryService::MicrosoftAD.EnableSso``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html#cfn-directoryservice-microsoftad-enablesso
         """
-        return self._values.get("enable_sso")
+        result = self._values.get("enable_sso")
+        return result
 
     @builtins.property
-    def short_name(self) -> typing.Optional[str]:
+    def short_name(self) -> typing.Optional[builtins.str]:
         """``AWS::DirectoryService::MicrosoftAD.ShortName``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html#cfn-directoryservice-microsoftad-shortname
         """
-        return self._values.get("short_name")
+        result = self._values.get("short_name")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -437,16 +460,16 @@ class CfnSimpleAD(
     def __init__(
         self,
         scope: aws_cdk.core.Construct,
-        id: str,
+        id: builtins.str,
         *,
-        name: str,
-        password: str,
-        size: str,
+        name: builtins.str,
+        password: builtins.str,
+        size: builtins.str,
         vpc_settings: typing.Union[aws_cdk.core.IResolvable, "VpcSettingsProperty"],
-        create_alias: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]] = None,
-        description: typing.Optional[str] = None,
-        enable_sso: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]] = None,
-        short_name: typing.Optional[str] = None,
+        create_alias: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]] = None,
+        description: typing.Optional[builtins.str] = None,
+        enable_sso: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]] = None,
+        short_name: typing.Optional[builtins.str] = None,
     ) -> None:
         """Create a new ``AWS::DirectoryService::SimpleAD``.
 
@@ -487,45 +510,46 @@ class CfnSimpleAD(
 
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(
-        self, props: typing.Mapping[str, typing.Any]
-    ) -> typing.Mapping[str, typing.Any]:
+        self,
+        props: typing.Mapping[builtins.str, typing.Any],
+    ) -> typing.Mapping[builtins.str, typing.Any]:
         """
         :param props: -
         """
         return jsii.invoke(self, "renderProperties", [props])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrAlias")
-    def attr_alias(self) -> str:
+    def attr_alias(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: Alias
         """
         return jsii.get(self, "attrAlias")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrDnsIpAddresses")
-    def attr_dns_ip_addresses(self) -> typing.List[str]:
+    def attr_dns_ip_addresses(self) -> typing.List[builtins.str]:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: DnsIpAddresses
         """
         return jsii.get(self, "attrDnsIpAddresses")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="name")
-    def name(self) -> str:
+    def name(self) -> builtins.str:
         """``AWS::DirectoryService::SimpleAD.Name``.
 
         see
@@ -533,13 +557,13 @@ class CfnSimpleAD(
         """
         return jsii.get(self, "name")
 
-    @name.setter
-    def name(self, value: str) -> None:
+    @name.setter # type: ignore
+    def name(self, value: builtins.str) -> None:
         jsii.set(self, "name", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="password")
-    def password(self) -> str:
+    def password(self) -> builtins.str:
         """``AWS::DirectoryService::SimpleAD.Password``.
 
         see
@@ -547,13 +571,13 @@ class CfnSimpleAD(
         """
         return jsii.get(self, "password")
 
-    @password.setter
-    def password(self, value: str) -> None:
+    @password.setter # type: ignore
+    def password(self, value: builtins.str) -> None:
         jsii.set(self, "password", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="size")
-    def size(self) -> str:
+    def size(self) -> builtins.str:
         """``AWS::DirectoryService::SimpleAD.Size``.
 
         see
@@ -561,11 +585,11 @@ class CfnSimpleAD(
         """
         return jsii.get(self, "size")
 
-    @size.setter
-    def size(self, value: str) -> None:
+    @size.setter # type: ignore
+    def size(self, value: builtins.str) -> None:
         jsii.set(self, "size", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="vpcSettings")
     def vpc_settings(
         self,
@@ -577,17 +601,18 @@ class CfnSimpleAD(
         """
         return jsii.get(self, "vpcSettings")
 
-    @vpc_settings.setter
+    @vpc_settings.setter # type: ignore
     def vpc_settings(
-        self, value: typing.Union[aws_cdk.core.IResolvable, "VpcSettingsProperty"]
+        self,
+        value: typing.Union[aws_cdk.core.IResolvable, "VpcSettingsProperty"],
     ) -> None:
         jsii.set(self, "vpcSettings", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="createAlias")
     def create_alias(
         self,
-    ) -> typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]:
+    ) -> typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]]:
         """``AWS::DirectoryService::SimpleAD.CreateAlias``.
 
         see
@@ -595,15 +620,16 @@ class CfnSimpleAD(
         """
         return jsii.get(self, "createAlias")
 
-    @create_alias.setter
+    @create_alias.setter # type: ignore
     def create_alias(
-        self, value: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]
+        self,
+        value: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]],
     ) -> None:
         jsii.set(self, "createAlias", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="description")
-    def description(self) -> typing.Optional[str]:
+    def description(self) -> typing.Optional[builtins.str]:
         """``AWS::DirectoryService::SimpleAD.Description``.
 
         see
@@ -611,15 +637,15 @@ class CfnSimpleAD(
         """
         return jsii.get(self, "description")
 
-    @description.setter
-    def description(self, value: typing.Optional[str]) -> None:
+    @description.setter # type: ignore
+    def description(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "description", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="enableSso")
     def enable_sso(
         self,
-    ) -> typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]:
+    ) -> typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]]:
         """``AWS::DirectoryService::SimpleAD.EnableSso``.
 
         see
@@ -627,15 +653,16 @@ class CfnSimpleAD(
         """
         return jsii.get(self, "enableSso")
 
-    @enable_sso.setter
+    @enable_sso.setter # type: ignore
     def enable_sso(
-        self, value: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]
+        self,
+        value: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]],
     ) -> None:
         jsii.set(self, "enableSso", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="shortName")
-    def short_name(self) -> typing.Optional[str]:
+    def short_name(self) -> typing.Optional[builtins.str]:
         """``AWS::DirectoryService::SimpleAD.ShortName``.
 
         see
@@ -643,8 +670,8 @@ class CfnSimpleAD(
         """
         return jsii.get(self, "shortName")
 
-    @short_name.setter
-    def short_name(self, value: typing.Optional[str]) -> None:
+    @short_name.setter # type: ignore
+    def short_name(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "shortName", value)
 
     @jsii.data_type(
@@ -653,7 +680,12 @@ class CfnSimpleAD(
         name_mapping={"subnet_ids": "subnetIds", "vpc_id": "vpcId"},
     )
     class VpcSettingsProperty:
-        def __init__(self, *, subnet_ids: typing.List[str], vpc_id: str) -> None:
+        def __init__(
+            self,
+            *,
+            subnet_ids: typing.List[builtins.str],
+            vpc_id: builtins.str,
+        ) -> None:
             """
             :param subnet_ids: ``CfnSimpleAD.VpcSettingsProperty.SubnetIds``.
             :param vpc_id: ``CfnSimpleAD.VpcSettingsProperty.VpcId``.
@@ -661,33 +693,37 @@ class CfnSimpleAD(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-directoryservice-simplead-vpcsettings.html
             """
-            self._values = {
+            self._values: typing.Dict[str, typing.Any] = {
                 "subnet_ids": subnet_ids,
                 "vpc_id": vpc_id,
             }
 
         @builtins.property
-        def subnet_ids(self) -> typing.List[str]:
+        def subnet_ids(self) -> typing.List[builtins.str]:
             """``CfnSimpleAD.VpcSettingsProperty.SubnetIds``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-directoryservice-simplead-vpcsettings.html#cfn-directoryservice-simplead-vpcsettings-subnetids
             """
-            return self._values.get("subnet_ids")
+            result = self._values.get("subnet_ids")
+            assert result is not None, "Required property 'subnet_ids' is missing"
+            return result
 
         @builtins.property
-        def vpc_id(self) -> str:
+        def vpc_id(self) -> builtins.str:
             """``CfnSimpleAD.VpcSettingsProperty.VpcId``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-directoryservice-simplead-vpcsettings.html#cfn-directoryservice-simplead-vpcsettings-vpcid
             """
-            return self._values.get("vpc_id")
+            result = self._values.get("vpc_id")
+            assert result is not None, "Required property 'vpc_id' is missing"
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -714,14 +750,14 @@ class CfnSimpleADProps:
     def __init__(
         self,
         *,
-        name: str,
-        password: str,
-        size: str,
+        name: builtins.str,
+        password: builtins.str,
+        size: builtins.str,
         vpc_settings: typing.Union[aws_cdk.core.IResolvable, "CfnSimpleAD.VpcSettingsProperty"],
-        create_alias: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]] = None,
-        description: typing.Optional[str] = None,
-        enable_sso: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]] = None,
-        short_name: typing.Optional[str] = None,
+        create_alias: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]] = None,
+        description: typing.Optional[builtins.str] = None,
+        enable_sso: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]] = None,
+        short_name: typing.Optional[builtins.str] = None,
     ) -> None:
         """Properties for defining a ``AWS::DirectoryService::SimpleAD``.
 
@@ -737,7 +773,7 @@ class CfnSimpleADProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "name": name,
             "password": password,
             "size": size,
@@ -753,31 +789,37 @@ class CfnSimpleADProps:
             self._values["short_name"] = short_name
 
     @builtins.property
-    def name(self) -> str:
+    def name(self) -> builtins.str:
         """``AWS::DirectoryService::SimpleAD.Name``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-name
         """
-        return self._values.get("name")
+        result = self._values.get("name")
+        assert result is not None, "Required property 'name' is missing"
+        return result
 
     @builtins.property
-    def password(self) -> str:
+    def password(self) -> builtins.str:
         """``AWS::DirectoryService::SimpleAD.Password``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-password
         """
-        return self._values.get("password")
+        result = self._values.get("password")
+        assert result is not None, "Required property 'password' is missing"
+        return result
 
     @builtins.property
-    def size(self) -> str:
+    def size(self) -> builtins.str:
         """``AWS::DirectoryService::SimpleAD.Size``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-size
         """
-        return self._values.get("size")
+        result = self._values.get("size")
+        assert result is not None, "Required property 'size' is missing"
+        return result
 
     @builtins.property
     def vpc_settings(
@@ -788,52 +830,58 @@ class CfnSimpleADProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-vpcsettings
         """
-        return self._values.get("vpc_settings")
+        result = self._values.get("vpc_settings")
+        assert result is not None, "Required property 'vpc_settings' is missing"
+        return result
 
     @builtins.property
     def create_alias(
         self,
-    ) -> typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]:
+    ) -> typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]]:
         """``AWS::DirectoryService::SimpleAD.CreateAlias``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-createalias
         """
-        return self._values.get("create_alias")
+        result = self._values.get("create_alias")
+        return result
 
     @builtins.property
-    def description(self) -> typing.Optional[str]:
+    def description(self) -> typing.Optional[builtins.str]:
         """``AWS::DirectoryService::SimpleAD.Description``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-description
         """
-        return self._values.get("description")
+        result = self._values.get("description")
+        return result
 
     @builtins.property
     def enable_sso(
         self,
-    ) -> typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]:
+    ) -> typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]]:
         """``AWS::DirectoryService::SimpleAD.EnableSso``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-enablesso
         """
-        return self._values.get("enable_sso")
+        result = self._values.get("enable_sso")
+        return result
 
     @builtins.property
-    def short_name(self) -> typing.Optional[str]:
+    def short_name(self) -> typing.Optional[builtins.str]:
         """``AWS::DirectoryService::SimpleAD.ShortName``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-shortname
         """
-        return self._values.get("short_name")
+        result = self._values.get("short_name")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
